# Genomics Module

The genomics module provides specialized functions for biological sequence analysis using LZSS factorization.

## FASTA Processing

```{eval-rst}
.. automodule:: noLZSS.genomics.fasta
   :members:
   :undoc-members:
   :show-inheritance:
```

## Sequence Utilities

```{eval-rst}
.. automodule:: noLZSS.genomics.sequences
   :members:
   :undoc-members:
   :show-inheritance:
```

## Plotting and Visualization

```{eval-rst}
.. automodule:: noLZSS.genomics.plots
   :members:
   :undoc-members:
   :show-inheritance:
```

## Genomics Package

```{eval-rst}
.. automodule:: noLZSS.genomics
   :members:
   :undoc-members:
   :show-inheritance:
```